@@ -1,8 +1,14 @@
 /* xalloc.c - memory allocation with error checking.
+   Copyright (C) 2000, 2001, 2002, 2003 Cris van Pelt
+   Copyright (C) 2003, 2004 Peter Palfrader
+
+   $Id: xalloc.c 409 2004-04-21 12:20:43Z weasel $
+
    Distributed under the terms of the Artistic License.
 */
 
 #include <stdio.h>
+#include <string.h>
 
 #ifdef HAVE_CONFIG_H
 #  include <config.h>
@@ -62,4 +68,15 @@ xmalloc(size_t size)
     return t;
 }
 
+inline char *
+xstrdup(const char *s)
+{
+    char *t;
+
+    if ((t = strdup(s)) == NULL)
+	error(EXIT_FAILURE, errno, "xstrdup: %p", (void *)t);
+
+    return t;
+}
+
 #endif /* USE_XALLOC */
